Module: Dmp
- Defined in:
- lib/dmp.rb,
lib/dmp/cli.rb,
lib/dmp/version.rb
Overview
Module to manage DMP operations
Defined Under Namespace
Classes: CLI
Constant Summary collapse
- VERSION =
"0.1.0"
Class Method Summary collapse
Class Method Details
.gen_passphrase(pass_length = 7) ⇒ Object
8 9 10 11 12 13 14 15 16 |
# File 'lib/dmp.rb', line 8 def self.gen_passphrase(pass_length = 7) # load eff_wordlist as a list and strip new lines pass_list = File.readlines(@eff_wordlist) pass_list.map(&:strip!) # randomize wordlist and strip it to the desired length random_pass = pass_list.shuffle[0...pass_length] random_pass end |